# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: types.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='types.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x0btypes.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"#\n\x0bStringInput\x12\x14\n\x0cstring_value\x18\x01 \x01(\t\"\x1c\n\tMinerList\x12\x0f\n\x07pubkeys\x18\x01 \x03(\x0c\"\x15\n\x04Hash\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x18\n\x07\x41\x64\x64ress\x12\r\n\x05value\x18\x01 \x01(\x0c\"\xb8\x01\n\x0bTransaction\x12\x1e\n\x0c\x66rom_address\x18\x01 \x01(\x0b\x32\x08.Address\x12\x1c\n\nto_address\x18\x02 \x01(\x0b\x32\x08.Address\x12\x18\n\x10ref_block_number\x18\x03 \x01(\x03\x12\x18\n\x10ref_block_prefix\x18\x04 \x01(\x0c\x12\x13\n\x0bmethod_name\x18\x05 \x01(\t\x12\x0e\n\x06params\x18\x06 \x01(\x0c\x12\x12\n\tsignature\x18\x90N \x01(\x0c\"\xf4\x02\n\x14\x45lectionVotingRecord\x12\x17\n\x05voter\x18\x01 \x01(\x0b\x32\x08.Address\x12\x11\n\tcandidate\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x13\n\x0bterm_number\x18\x04 \x01(\x03\x12\x16\n\x07vote_id\x18\x05 \x01(\x0b\x32\x05.Hash\x12\x11\n\tlock_time\x18\x06 \x01(\x03\x12\x34\n\x10unlock_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12withdraw_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0evote_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cis_withdrawn\x18\n \x01(\x08\x12\x0e\n\x06weight\x18\x0b \x01(\x03\x12\x18\n\x10is_change_target\x18\x0c \x01(\x08\"\xa3\x02\n\x0b\x45lectorVote\x12\'\n\x18\x61\x63tive_voting_record_ids\x18\x01 \x03(\x0b\x32\x05.Hash\x12*\n\x1bwithdrawn_voting_record_ids\x18\x02 \x03(\x0b\x32\x05.Hash\x12!\n\x19\x61\x63tive_voted_votes_amount\x18\x03 \x01(\x03\x12\x1e\n\x16\x61ll_voted_votes_amount\x18\x04 \x01(\x03\x12\x34\n\x15\x61\x63tive_voting_records\x18\x05 \x03(\x0b\x32\x15.ElectionVotingRecord\x12\x36\n\x17withdrawn_votes_records\x18\x06 \x03(\x0b\x32\x15.ElectionVotingRecord\x12\x0e\n\x06pubkey\x18\x07 \x01(\x0c\"\xdb\x02\n\rCandidateVote\x12\x30\n!obtained_active_voting_record_ids\x18\x01 \x03(\x0b\x32\x05.Hash\x12\x33\n$obtained_withdrawn_voting_record_ids\x18\x02 \x03(\x0b\x32\x05.Hash\x12*\n\"obtained_active_voted_votes_amount\x18\x03 \x01(\x03\x12\'\n\x1f\x61ll_obtained_voted_votes_amount\x18\x04 \x01(\x03\x12=\n\x1eobtained_active_voting_records\x18\x05 \x03(\x0b\x32\x15.ElectionVotingRecord\x12?\n obtained_withdrawn_votes_records\x18\x06 \x03(\x0b\x32\x15.ElectionVotingRecord\x12\x0e\n\x06pubkey\x18\x07 \x01(\x0c\"\x1f\n\x0ePublicKeysList\x12\r\n\x05value\x18\x01 \x03(\x0c\"9\n\x17\x43ontractDeploymentInput\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\x11\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x0c\">\n\x13\x43ontractUpdateInput\x12\x19\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x08.Address\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x0c\"\x8a\x01\n\x17\x43rossChainTransferInput\x12\x14\n\x02to\x18\x01 \x01(\x0b\x32\x08.Address\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x0c\n\x04memo\x18\x04 \x01(\t\x12\x13\n\x0bto_chain_id\x18\x05 \x01(\x05\x12\x16\n\x0eissue_chain_id\x18\x06 \x01(\x05\"8\n\nMerklePath\x12*\n\x11merkle_path_nodes\x18\x01 \x03(\x0b\x32\x0f.MerklePathNode\"A\n\x0eMerklePathNode\x12\x13\n\x04hash\x18\x01 \x01(\x0b\x32\x05.Hash\x12\x1a\n\x12is_left_child_node\x18\x02 \x01(\x08\"\x97\x01\n\x1b\x43rossChainReceiveTokenInput\x12\x15\n\rfrom_chain_id\x18\x01 \x01(\x05\x12\x1b\n\x13parent_chain_height\x18\x02 \x01(\x03\x12\"\n\x1atransfer_transaction_bytes\x18\x03 \x01(\x0c\x12 \n\x0bmerkle_path\x18\x04 \x01(\x0b\x32\x0b.MerklePath\"#\n\x11GetTokenInfoInput\x12\x0e\n\x06symbol\x18\x01 \x01(\t\":\n\x0fGetBalanceInput\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x17\n\x05owner\x18\x02 \x01(\x0b\x32\x08.Address\"L\n\x10GetBalanceOutput\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x17\n\x05owner\x18\x02 \x01(\x0b\x32\x08.Address\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\x03\"P\n\nIssueInput\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\x12\x0c\n\x04memo\x18\x03 \x01(\t\x12\x14\n\x02to\x18\x04 \x01(\x0b\x32\x08.Address\"S\n\rTransferInput\x12\x14\n\x02to\x18\x01 \x01(\x0b\x32\x08.Address\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x0c\n\x04memo\x18\x04 \x01(\tb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_STRINGINPUT = _descriptor.Descriptor(
  name='StringInput',
  full_name='StringInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='StringInput.string_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=83,
)


_MINERLIST = _descriptor.Descriptor(
  name='MinerList',
  full_name='MinerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkeys', full_name='MinerList.pubkeys', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=113,
)


_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='Hash.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=136,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='Address.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=162,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_address', full_name='Transaction.from_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_address', full_name='Transaction.to_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref_block_number', full_name='Transaction.ref_block_number', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref_block_prefix', full_name='Transaction.ref_block_prefix', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='Transaction.method_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='Transaction.params', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='Transaction.signature', index=6,
      number=10000, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=349,
)


_ELECTIONVOTINGRECORD = _descriptor.Descriptor(
  name='ElectionVotingRecord',
  full_name='ElectionVotingRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voter', full_name='ElectionVotingRecord.voter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='ElectionVotingRecord.candidate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='ElectionVotingRecord.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='term_number', full_name='ElectionVotingRecord.term_number', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_id', full_name='ElectionVotingRecord.vote_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lock_time', full_name='ElectionVotingRecord.lock_time', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unlock_timestamp', full_name='ElectionVotingRecord.unlock_timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdraw_timestamp', full_name='ElectionVotingRecord.withdraw_timestamp', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_timestamp', full_name='ElectionVotingRecord.vote_timestamp', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_withdrawn', full_name='ElectionVotingRecord.is_withdrawn', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='ElectionVotingRecord.weight', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_change_target', full_name='ElectionVotingRecord.is_change_target', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=724,
)


_ELECTORVOTE = _descriptor.Descriptor(
  name='ElectorVote',
  full_name='ElectorVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_voting_record_ids', full_name='ElectorVote.active_voting_record_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawn_voting_record_ids', full_name='ElectorVote.withdrawn_voting_record_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_voted_votes_amount', full_name='ElectorVote.active_voted_votes_amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_voted_votes_amount', full_name='ElectorVote.all_voted_votes_amount', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_voting_records', full_name='ElectorVote.active_voting_records', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='withdrawn_votes_records', full_name='ElectorVote.withdrawn_votes_records', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='ElectorVote.pubkey', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=1018,
)


_CANDIDATEVOTE = _descriptor.Descriptor(
  name='CandidateVote',
  full_name='CandidateVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='obtained_active_voting_record_ids', full_name='CandidateVote.obtained_active_voting_record_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obtained_withdrawn_voting_record_ids', full_name='CandidateVote.obtained_withdrawn_voting_record_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obtained_active_voted_votes_amount', full_name='CandidateVote.obtained_active_voted_votes_amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all_obtained_voted_votes_amount', full_name='CandidateVote.all_obtained_voted_votes_amount', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obtained_active_voting_records', full_name='CandidateVote.obtained_active_voting_records', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obtained_withdrawn_votes_records', full_name='CandidateVote.obtained_withdrawn_votes_records', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='CandidateVote.pubkey', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1368,
)


_PUBLICKEYSLIST = _descriptor.Descriptor(
  name='PublicKeysList',
  full_name='PublicKeysList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='PublicKeysList.value', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1401,
)


_CONTRACTDEPLOYMENTINPUT = _descriptor.Descriptor(
  name='ContractDeploymentInput',
  full_name='ContractDeploymentInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='ContractDeploymentInput.category', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='ContractDeploymentInput.code', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1403,
  serialized_end=1460,
)


_CONTRACTUPDATEINPUT = _descriptor.Descriptor(
  name='ContractUpdateInput',
  full_name='ContractUpdateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='ContractUpdateInput.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='ContractUpdateInput.code', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1462,
  serialized_end=1524,
)


_CROSSCHAINTRANSFERINPUT = _descriptor.Descriptor(
  name='CrossChainTransferInput',
  full_name='CrossChainTransferInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='to', full_name='CrossChainTransferInput.to', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='CrossChainTransferInput.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='CrossChainTransferInput.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='CrossChainTransferInput.memo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_chain_id', full_name='CrossChainTransferInput.to_chain_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issue_chain_id', full_name='CrossChainTransferInput.issue_chain_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1665,
)


_MERKLEPATH = _descriptor.Descriptor(
  name='MerklePath',
  full_name='MerklePath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='merkle_path_nodes', full_name='MerklePath.merkle_path_nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1723,
)


_MERKLEPATHNODE = _descriptor.Descriptor(
  name='MerklePathNode',
  full_name='MerklePathNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='MerklePathNode.hash', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_left_child_node', full_name='MerklePathNode.is_left_child_node', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1790,
)


_CROSSCHAINRECEIVETOKENINPUT = _descriptor.Descriptor(
  name='CrossChainReceiveTokenInput',
  full_name='CrossChainReceiveTokenInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_chain_id', full_name='CrossChainReceiveTokenInput.from_chain_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_chain_height', full_name='CrossChainReceiveTokenInput.parent_chain_height', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_transaction_bytes', full_name='CrossChainReceiveTokenInput.transfer_transaction_bytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merkle_path', full_name='CrossChainReceiveTokenInput.merkle_path', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=1944,
)


_GETTOKENINFOINPUT = _descriptor.Descriptor(
  name='GetTokenInfoInput',
  full_name='GetTokenInfoInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='GetTokenInfoInput.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1946,
  serialized_end=1981,
)


_GETBALANCEINPUT = _descriptor.Descriptor(
  name='GetBalanceInput',
  full_name='GetBalanceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='GetBalanceInput.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='GetBalanceInput.owner', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1983,
  serialized_end=2041,
)


_GETBALANCEOUTPUT = _descriptor.Descriptor(
  name='GetBalanceOutput',
  full_name='GetBalanceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='GetBalanceOutput.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='GetBalanceOutput.owner', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance', full_name='GetBalanceOutput.balance', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2043,
  serialized_end=2119,
)


_ISSUEINPUT = _descriptor.Descriptor(
  name='IssueInput',
  full_name='IssueInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='IssueInput.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='IssueInput.amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='IssueInput.memo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='IssueInput.to', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2201,
)


_TRANSFERINPUT = _descriptor.Descriptor(
  name='TransferInput',
  full_name='TransferInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='to', full_name='TransferInput.to', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='TransferInput.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='TransferInput.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo', full_name='TransferInput.memo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2203,
  serialized_end=2286,
)

_TRANSACTION.fields_by_name['from_address'].message_type = _ADDRESS
_TRANSACTION.fields_by_name['to_address'].message_type = _ADDRESS
_ELECTIONVOTINGRECORD.fields_by_name['voter'].message_type = _ADDRESS
_ELECTIONVOTINGRECORD.fields_by_name['vote_id'].message_type = _HASH
_ELECTIONVOTINGRECORD.fields_by_name['unlock_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ELECTIONVOTINGRECORD.fields_by_name['withdraw_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ELECTIONVOTINGRECORD.fields_by_name['vote_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ELECTORVOTE.fields_by_name['active_voting_record_ids'].message_type = _HASH
_ELECTORVOTE.fields_by_name['withdrawn_voting_record_ids'].message_type = _HASH
_ELECTORVOTE.fields_by_name['active_voting_records'].message_type = _ELECTIONVOTINGRECORD
_ELECTORVOTE.fields_by_name['withdrawn_votes_records'].message_type = _ELECTIONVOTINGRECORD
_CANDIDATEVOTE.fields_by_name['obtained_active_voting_record_ids'].message_type = _HASH
_CANDIDATEVOTE.fields_by_name['obtained_withdrawn_voting_record_ids'].message_type = _HASH
_CANDIDATEVOTE.fields_by_name['obtained_active_voting_records'].message_type = _ELECTIONVOTINGRECORD
_CANDIDATEVOTE.fields_by_name['obtained_withdrawn_votes_records'].message_type = _ELECTIONVOTINGRECORD
_CONTRACTUPDATEINPUT.fields_by_name['address'].message_type = _ADDRESS
_CROSSCHAINTRANSFERINPUT.fields_by_name['to'].message_type = _ADDRESS
_MERKLEPATH.fields_by_name['merkle_path_nodes'].message_type = _MERKLEPATHNODE
_MERKLEPATHNODE.fields_by_name['hash'].message_type = _HASH
_CROSSCHAINRECEIVETOKENINPUT.fields_by_name['merkle_path'].message_type = _MERKLEPATH
_GETBALANCEINPUT.fields_by_name['owner'].message_type = _ADDRESS
_GETBALANCEOUTPUT.fields_by_name['owner'].message_type = _ADDRESS
_ISSUEINPUT.fields_by_name['to'].message_type = _ADDRESS
_TRANSFERINPUT.fields_by_name['to'].message_type = _ADDRESS
DESCRIPTOR.message_types_by_name['StringInput'] = _STRINGINPUT
DESCRIPTOR.message_types_by_name['MinerList'] = _MINERLIST
DESCRIPTOR.message_types_by_name['Hash'] = _HASH
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['ElectionVotingRecord'] = _ELECTIONVOTINGRECORD
DESCRIPTOR.message_types_by_name['ElectorVote'] = _ELECTORVOTE
DESCRIPTOR.message_types_by_name['CandidateVote'] = _CANDIDATEVOTE
DESCRIPTOR.message_types_by_name['PublicKeysList'] = _PUBLICKEYSLIST
DESCRIPTOR.message_types_by_name['ContractDeploymentInput'] = _CONTRACTDEPLOYMENTINPUT
DESCRIPTOR.message_types_by_name['ContractUpdateInput'] = _CONTRACTUPDATEINPUT
DESCRIPTOR.message_types_by_name['CrossChainTransferInput'] = _CROSSCHAINTRANSFERINPUT
DESCRIPTOR.message_types_by_name['MerklePath'] = _MERKLEPATH
DESCRIPTOR.message_types_by_name['MerklePathNode'] = _MERKLEPATHNODE
DESCRIPTOR.message_types_by_name['CrossChainReceiveTokenInput'] = _CROSSCHAINRECEIVETOKENINPUT
DESCRIPTOR.message_types_by_name['GetTokenInfoInput'] = _GETTOKENINFOINPUT
DESCRIPTOR.message_types_by_name['GetBalanceInput'] = _GETBALANCEINPUT
DESCRIPTOR.message_types_by_name['GetBalanceOutput'] = _GETBALANCEOUTPUT
DESCRIPTOR.message_types_by_name['IssueInput'] = _ISSUEINPUT
DESCRIPTOR.message_types_by_name['TransferInput'] = _TRANSFERINPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StringInput = _reflection.GeneratedProtocolMessageType('StringInput', (_message.Message,), {
  'DESCRIPTOR' : _STRINGINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:StringInput)
  })
_sym_db.RegisterMessage(StringInput)

MinerList = _reflection.GeneratedProtocolMessageType('MinerList', (_message.Message,), {
  'DESCRIPTOR' : _MINERLIST,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:MinerList)
  })
_sym_db.RegisterMessage(MinerList)

Hash = _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
  'DESCRIPTOR' : _HASH,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:Hash)
  })
_sym_db.RegisterMessage(Hash)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:Address)
  })
_sym_db.RegisterMessage(Address)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTION,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:Transaction)
  })
_sym_db.RegisterMessage(Transaction)

ElectionVotingRecord = _reflection.GeneratedProtocolMessageType('ElectionVotingRecord', (_message.Message,), {
  'DESCRIPTOR' : _ELECTIONVOTINGRECORD,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:ElectionVotingRecord)
  })
_sym_db.RegisterMessage(ElectionVotingRecord)

ElectorVote = _reflection.GeneratedProtocolMessageType('ElectorVote', (_message.Message,), {
  'DESCRIPTOR' : _ELECTORVOTE,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:ElectorVote)
  })
_sym_db.RegisterMessage(ElectorVote)

CandidateVote = _reflection.GeneratedProtocolMessageType('CandidateVote', (_message.Message,), {
  'DESCRIPTOR' : _CANDIDATEVOTE,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:CandidateVote)
  })
_sym_db.RegisterMessage(CandidateVote)

PublicKeysList = _reflection.GeneratedProtocolMessageType('PublicKeysList', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEYSLIST,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:PublicKeysList)
  })
_sym_db.RegisterMessage(PublicKeysList)

ContractDeploymentInput = _reflection.GeneratedProtocolMessageType('ContractDeploymentInput', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTDEPLOYMENTINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:ContractDeploymentInput)
  })
_sym_db.RegisterMessage(ContractDeploymentInput)

ContractUpdateInput = _reflection.GeneratedProtocolMessageType('ContractUpdateInput', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTUPDATEINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:ContractUpdateInput)
  })
_sym_db.RegisterMessage(ContractUpdateInput)

CrossChainTransferInput = _reflection.GeneratedProtocolMessageType('CrossChainTransferInput', (_message.Message,), {
  'DESCRIPTOR' : _CROSSCHAINTRANSFERINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:CrossChainTransferInput)
  })
_sym_db.RegisterMessage(CrossChainTransferInput)

MerklePath = _reflection.GeneratedProtocolMessageType('MerklePath', (_message.Message,), {
  'DESCRIPTOR' : _MERKLEPATH,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:MerklePath)
  })
_sym_db.RegisterMessage(MerklePath)

MerklePathNode = _reflection.GeneratedProtocolMessageType('MerklePathNode', (_message.Message,), {
  'DESCRIPTOR' : _MERKLEPATHNODE,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:MerklePathNode)
  })
_sym_db.RegisterMessage(MerklePathNode)

CrossChainReceiveTokenInput = _reflection.GeneratedProtocolMessageType('CrossChainReceiveTokenInput', (_message.Message,), {
  'DESCRIPTOR' : _CROSSCHAINRECEIVETOKENINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:CrossChainReceiveTokenInput)
  })
_sym_db.RegisterMessage(CrossChainReceiveTokenInput)

GetTokenInfoInput = _reflection.GeneratedProtocolMessageType('GetTokenInfoInput', (_message.Message,), {
  'DESCRIPTOR' : _GETTOKENINFOINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:GetTokenInfoInput)
  })
_sym_db.RegisterMessage(GetTokenInfoInput)

GetBalanceInput = _reflection.GeneratedProtocolMessageType('GetBalanceInput', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCEINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:GetBalanceInput)
  })
_sym_db.RegisterMessage(GetBalanceInput)

GetBalanceOutput = _reflection.GeneratedProtocolMessageType('GetBalanceOutput', (_message.Message,), {
  'DESCRIPTOR' : _GETBALANCEOUTPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:GetBalanceOutput)
  })
_sym_db.RegisterMessage(GetBalanceOutput)

IssueInput = _reflection.GeneratedProtocolMessageType('IssueInput', (_message.Message,), {
  'DESCRIPTOR' : _ISSUEINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:IssueInput)
  })
_sym_db.RegisterMessage(IssueInput)

TransferInput = _reflection.GeneratedProtocolMessageType('TransferInput', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERINPUT,
  '__module__' : 'types_pb2'
  # @@protoc_insertion_point(class_scope:TransferInput)
  })
_sym_db.RegisterMessage(TransferInput)


# @@protoc_insertion_point(module_scope)
